#!/usr/bin/env python

""" Quick script for installing the output of pypeit_identify

The output of pypeit_identify needs to be placed into the reid_arxiv directory
to be used by the main reduction pipeline.  This code is a quick and dirty way
of doing that for LDT/DeVeny data until such time as proper templates can be
added to the main code base.

Run this script from the command line in the directory containing the output
from pypeit_identify via:

python install_deveny_arxiv.py [wvarxiv.fits or whatever you renamed it to]

NOTE: You must be in whatever virtual environment you have for pypeit.

TEB, 2022 Feb 07
"""

import os
from pkg_resources import resource_filename

from pypeit.io import create_symlink


def main(filenames):

    arxiv_dir = os.path.join(resource_filename('pypeit', 'data'), 'arc_lines', 'reid_arxiv')
    
    # Create a symlink for each file
    for f in filenames:
        create_symlink(f, arxiv_dir, overwrite=True)
    
    print(f"To verify your reid_arxiv file is readbale by PypeIt, type: ls {arxiv_dir}")


if __name__ == '__main__':
# Set up the environment to import the program
    import argparse

    # Parse command line arguments
    parser = argparse.ArgumentParser(prog='install_deveny_arxiv',
                        description='Add wavelength calibrations from pypeit_identify to reid_arxiv')
    parser.add_argument('files', action='store', type=str, nargs='+',
                        help='File(s) to install as reid_arxiv for use with full_template')
    args = parser.parse_args()

    main(args.files)
